==> php-json-schema_5.2.12.orig.tar.xz: php-json-schema-5.2.12/tests/Constraints/UniqueItemsTest.php <==
<?php

/*
 * This file is part of the JsonSchema package.
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */

namespace JsonSchema\Tests\Constraints;

class UniqueItemsTest extends BaseTestCase
{
    protected $validateSchema = true;

    public function getInvalidTests()
    {
        return array(
            array(
                '[1,2,2]',
                '{
                  "type":"array",
                  "uniqueItems": true
                }'
            ),
            array(
                '[{"a":"b"},{"a":"c"},{"a":"b"}]',
                '{
                  "type":"array",
                  "uniqueItems": true
                }'
            ),
            array(
                '[{"foo": {"bar" : {"baz" : true}}}, {"foo": {"bar" : {"baz" : true}}}]',
                '{
                    "type": "array",
                    "uniqueItems": true
                }'
            ),
            array(
                '[1.0, 1.00, 1]',
                '{
                    "type": "array",
                    "uniqueItems": true
                }'
            ),
            array(
                '[["foo"], ["foo"]]',
                '{
                    "type": "array",
                    "uniqueItems": true
                }'
            ),
            array(
                '[{}, [1], true, null, {}, 1]',
                '{
                    "type": "array",
                    "uniqueItems": true
                }'
            )
        );
    }

    public function getValidTests()
    {
        return array(
            array(
                '[1,2,3]',
                '{
                  "type":"array",
                  "uniqueItems": true
                }'
            ),
            array(
                '[{"foo": 12}, {"bar": false}]',
                '{
                    "type": "array",
                    "uniqueItems": true
                }'
            ),
            array(
                '[1, true]',
                '{
                    "type": "array",
                    "uniqueItems": true
                }'
            ),
            array(
                '[0, false]',
                '{
                    "type": "array",
                    "uniqueItems": true
                }'
            ),
            array(
                '[{"foo": {"bar" : {"baz" : true}}}, {"foo": {"bar" : {"baz" : false}}}]',
                '{
                    "type": "array",
                    "uniqueItems": true
                }'
            ),
            array(
                '[["foo"], ["bar"]]',
                '{
                    "type": "array",
                    "uniqueItems": true
                }'
            ),
            array(
                '[{}, [1], true, null, 1]',
                '{
                    "type": "array",
                    "uniqueItems": true
                }'
            ),
            // below equals the invalid tests, but with uniqueItems set to false
            array(
                '[1,2,2]',
                '{
                  "type":"array",
                  "uniqueItems": false
                }'
            ),
            array(
                '[{"a":"b"},{"a":"c"},{"a":"b"}]',
                '{
                  "type":"array",
                  "uniqueItems": false
                }'
            ),
            array(
                '[{"foo": {"bar" : {"baz" : true}}}, {"foo": {"bar" : {"baz" : true}}}]',
                '{
                    "type": "array",
                    "uniqueItems": false
                }'
            ),
            array(
                '[1.0, 1.00, 1]',
                '{
                    "type": "array",
                    "uniqueItems": false
                }'
            ),
            array(
                '[["foo"], ["foo"]]',
                '{
                    "type": "array",
                    "uniqueItems": false
                }'
            ),
            array(
                '[{}, [1], true, null, {}, 1]',
                '{
                    "type": "array",
                    "uniqueItems": false
                }'
            )
        );
    }
}

==> php-json-schema_6.4.1.orig.tar.xz: php-json-schema-6.4.1/tests/Constraints/UniqueItemsTest.php <==
<?php

/*
 * This file is part of the JsonSchema package.
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */

namespace JsonSchema\Tests\Constraints;

class UniqueItemsTest extends BaseTestCase
{
    protected $validateSchema = true;

    public function getInvalidTests(): array
    {
        return [
            [
                '[1,2,2]',
                '{
                  "type":"array",
                  "uniqueItems": true
                }'
            ],
            [
                '[{"a":"b"},{"a":"c"},{"a":"b"}]',
                '{
                  "type":"array",
                  "uniqueItems": true
                }'
            ],
            [
                '[{"foo": {"bar" : {"baz" : true}}}, {"foo": {"bar" : {"baz" : true}}}]',
                '{
                    "type": "array",
                    "uniqueItems": true
                }'
            ],
            [
                '[1.0, 1.00, 1]',
                '{
                    "type": "array",
                    "uniqueItems": true
                }'
            ],
            [
                '[["foo"], ["foo"]]',
                '{
                    "type": "array",
                    "uniqueItems": true
                }'
            ],
            [
                '[{}, [1], true, null, {}, 1]',
                '{
                    "type": "array",
                    "uniqueItems": true
                }'
            ]
        ];
    }

    public function getValidTests(): array
    {
        return [
            [
                '[1,2,3]',
                '{
                  "type":"array",
                  "uniqueItems": true
                }'
            ],
            [
                '[{"foo": 12}, {"bar": false}]',
                '{
                    "type": "array",
                    "uniqueItems": true
                }'
            ],
            [
                '[1, true]',
                '{
                    "type": "array",
                    "uniqueItems": true
                }'
            ],
            [
                '[0, false]',
                '{
                    "type": "array",
                    "uniqueItems": true
                }'
            ],
            [
                '[{"foo": {"bar" : {"baz" : true}}}, {"foo": {"bar" : {"baz" : false}}}]',
                '{
                    "type": "array",
                    "uniqueItems": true
                }'
            ],
            [
                '[["foo"], ["bar"]]',
                '{
                    "type": "array",
                    "uniqueItems": true
                }'
            ],
            [
                '[{}, [1], true, null, 1]',
                '{
                    "type": "array",
                    "uniqueItems": true
                }'
            ],
            // below equals the invalid tests, but with uniqueItems set to false
            [
                '[1,2,2]',
                '{
                  "type":"array",
                  "uniqueItems": false
                }'
            ],
            [
                '[{"a":"b"},{"a":"c"},{"a":"b"}]',
                '{
                  "type":"array",
                  "uniqueItems": false
                }'
            ],
            [
                '[{"foo": {"bar" : {"baz" : true}}}, {"foo": {"bar" : {"baz" : true}}}]',
                '{
                    "type": "array",
                    "uniqueItems": false
                }'
            ],
            [
                '[1.0, 1.00, 1]',
                '{
                    "type": "array",
                    "uniqueItems": false
                }'
            ],
            [
                '[["foo"], ["foo"]]',
                '{
                    "type": "array",
                    "uniqueItems": false
                }'
            ],
            [
                '[{}, [1], true, null, {}, 1]',
                '{
                    "type": "array",
                    "uniqueItems": false
                }'
            ]
        ];
    }
}
